@@ -169,6 +169,52 @@ def test_entity_joiner_join_comma_separated_locs():
     }
 
 
+def test_entity_joiner_join_and_separated_people():
+    # Positive example: 'Katharine' should be given alternative entity text 'Katharine Parsons'
+    nlp = spacy.blank("en")
+    doc = nlp(
+        "Katharine and Charles Parsons had a lasting impact on electrical engineering beyond their lifetime. Charles' work on electrical turbines, supported by Katherine, led to the large-scale introduction of electricity generated by steam turbines."
+    )
+    doc.ents = [
+        spacy.tokens.Span(doc, 0, 1, "PERSON"),
+        spacy.tokens.Span(doc, 2, 4, "PERSON"),
+        spacy.tokens.Span(doc, 15, 16, "PERSON"),
+        spacy.tokens.Span(doc, 24, 25, "PERSON"),
+    ]
+
+    e_j = pipeline.EntityJoiner(nlp, "entity_joiner")
+    doc_modified = e_j._detect_joined_person_entities(doc)
+
+    assert len(doc_modified.ents) == len(doc.ents)
+    assert [(ent.start, ent.end, ent.text, ent.label_) for ent in doc.ents] == [
+        (ent.start, ent.end, ent.text, ent.label_) for ent in doc_modified.ents
+    ]
+    assert doc.ents[0]._.alt_ent_text == "Katharine Parsons"
+    assert [ent._.alt_ent_text is None for ent in doc.ents[1:]]
+
+    # Negative example: 'Katharine Hepburn' should not be given alternative entity text
+    nlp = spacy.blank("en")
+    doc = nlp(
+        "Katharine Hepburn and Charles Parsons had a lasting impact on electrical engineering beyond their lifetime. Charles' work on electrical turbines, supported by Katherine, led to the large-scale introduction of electricity generated by steam turbines."
+    )
+    doc.ents = [
+        spacy.tokens.Span(doc, 0, 2, "PERSON"),
+        spacy.tokens.Span(doc, 3, 5, "PERSON"),
+        spacy.tokens.Span(doc, 16, 17, "PERSON"),
+        spacy.tokens.Span(doc, 25, 26, "PERSON"),
+    ]
+
+    e_j = pipeline.EntityJoiner(nlp, "entity_joiner")
+    doc_modified = e_j._detect_joined_person_entities(doc)
+
+    assert len(doc_modified.ents) == len(doc.ents)
+    assert [(ent.start, ent.end, ent.text, ent.label_) for ent in doc.ents] == [
+        (ent.start, ent.end, ent.text, ent.label_) for ent in doc_modified.ents
+    ]
+    assert all([ent._.alt_ent_text is None for ent in doc.ents])
+    assert [ent._.alt_ent_text is None for ent in doc.ents[1:]]
+
+
 def test_duplicate_entity_detector():
     """
     Test that the component can be created and imported into a new nlp object,
@@ -185,6 +231,40 @@ def test_duplicate_entity_detector():
     assert isinstance(doc, spacy.tokens.Doc)
 
 
+def test_entity_joiner_and_separated_people_and_duplicate_entity_detector_person():
+    """Test that the `ent._.alt_ent_text` attribute set by EntityJoiner is used by DuplicateEntityDetector
+    to exclude future mentions of that person. E.g.:
+    a) 'Katharine and Charles Parsons' mentioned, followed by a separate mention of 'Katharine' later on
+    b) EntityJoiner adds 'Katharine Parsons' as alt_ent_text attribute to 'Katharine'
+    c) DuplicateEntityDetector uses alt_ent_text attribute to mark later mention of 'Katharine' as duplicated
+    """
+
+    nlp = spacy.blank("en")
+    ent_joiner = pipeline.EntityJoiner(nlp, "entity_joiner")
+    dupl_ent_detector = pipeline.DuplicateEntityDetector(
+        nlp, "duplicate_entity_detector"
+    )
+
+    text = "Katharine and Charles Parsons had a lasting impact on electrical engineering beyond their lifetime. Charles' work on electrical turbines, supported by Katharine, led to the large-scale introduction of electricity generated by steam turbines. This is a system still in use today."
+    doc = nlp(text)
+    doc.ents = [
+        spacy.tokens.Span(doc, 0, 1, "PERSON"),
+        spacy.tokens.Span(doc, 2, 4, "PERSON"),
+        spacy.tokens.Span(doc, 15, 16, "PERSON"),
+        spacy.tokens.Span(doc, 24, 25, "PERSON"),
+        spacy.tokens.Span(doc, 47, 48, "DATE"),
+    ]
+    modified_doc = dupl_ent_detector(ent_joiner(doc))
+
+    assert len(modified_doc.ents) == len(doc.ents)
+
+    # first 'Katharine' has attribute with her full name
+    assert modified_doc.ents[0]._.alt_ent_text == "Katharine Parsons"
+
+    # second 'Katharine' marked as duplicate
+    assert modified_doc.ents[3]._.entity_duplicate is True
+
+
 def test_duplicate_entity_detector_person():
     nlp = spacy.blank("en")
     dupl_ent_detector = pipeline.DuplicateEntityDetector(
